@@ -27,10 +27,10 @@
 #endif
 
 #include <string.h>
-#include <bonobo/bonobo-i18n.h>
 
 #include "e-cal-backend-contacts.h"
 
+#include <glib/gi18n-lib.h>
 #include <libedataserver/e-xml-hash-utils.h>
 #include <libecal/e-cal-recur.h>
 #include <libecal/e-cal-util.h>
@@ -176,7 +176,7 @@ contact_record_free (ContactRecord *cr)
 	if (cr->comp_birthday) {
 		comp_str = e_cal_component_get_as_string (cr->comp_birthday);
 		e_cal_component_get_uid (cr->comp_birthday, &uid);
-		e_cal_backend_notify_object_removed (E_CAL_BACKEND (cr->cbc), uid, comp_str);
+		e_cal_backend_notify_object_removed (E_CAL_BACKEND (cr->cbc), uid, comp_str, NULL);
 		g_free (comp_str);
 		g_object_unref (G_OBJECT (cr->comp_birthday));
 	}
@@ -185,7 +185,7 @@ contact_record_free (ContactRecord *cr)
 	if (cr->comp_anniversary) {
 		comp_str = e_cal_component_get_as_string (cr->comp_anniversary);
 		e_cal_component_get_uid (cr->comp_anniversary, &uid);
-		e_cal_backend_notify_object_removed (E_CAL_BACKEND (cr->cbc), uid, comp_str);
+		e_cal_backend_notify_object_removed (E_CAL_BACKEND (cr->cbc), uid, comp_str, NULL);
 		g_free (comp_str);
 		g_object_unref (G_OBJECT (cr->comp_anniversary));
 	}
@@ -903,6 +903,7 @@ e_cal_backend_contacts_finalize (GObject *object)
 	cbc = E_CAL_BACKEND_CONTACTS (object);
 	priv = cbc->priv;
 
+	g_hash_table_destroy (priv->addressbooks);
         g_hash_table_destroy (priv->tracked_contacts);
         g_hash_table_destroy (priv->zones);
         
@@ -932,6 +933,8 @@ e_cal_backend_contacts_init (ECalBackendContacts *cbc, ECalBackendContactsClass
 	priv->default_zone = icaltimezone_get_utc_timezone ();
         
 	cbc->priv = priv;
+
+	e_cal_backend_sync_set_lock (E_CAL_BACKEND_SYNC (cbc), TRUE);
 }
 
 /* Class initialization function for the contacts backend */
