@@ -302,7 +302,11 @@ e_cal_backend_cache_get_component (ECalBackendCache *cache, const char *uid, con
 		icalcomp = icalparser_parse_string (comp_str);
 		if (icalcomp) {
 			comp = e_cal_component_new ();
-			e_cal_component_set_icalcomponent (comp, icalcomp);
+			if (!e_cal_component_set_icalcomponent (comp, icalcomp)) {
+				icalcomponent_free (icalcomp);
+				g_object_unref (comp);
+				comp = NULL;
+			}
 		}
 	}
 
@@ -402,8 +406,12 @@ e_cal_backend_cache_get_components (ECalBackendCache *cache)
 				kind = icalcomponent_isa (icalcomp);
 				if (kind == ICAL_VEVENT_COMPONENT || kind == ICAL_VTODO_COMPONENT) {
 					comp = e_cal_component_new ();
-					e_cal_component_set_icalcomponent (comp, icalcomp);
-					list = g_list_append (list, comp);
+					if (e_cal_component_set_icalcomponent (comp, icalcomp))
+						list = g_list_append (list, comp);
+					else {
+						icalcomponent_free (icalcomp);
+						g_object_unref (comp);
+					}
 				} else
 					icalcomponent_free (icalcomp);
                         }
@@ -606,3 +614,28 @@ e_cal_backend_cache_get_marker (ECalBackendCache *cache)
 		return "";
 	return NULL;
 }
+
+gboolean
+e_cal_backend_cache_put_server_utc_time (ECalBackendCache *cache, char *utc_str)
+{
+	char *value;
+	gboolean ret_val = FALSE;
+	
+	g_return_val_if_fail (E_IS_CAL_BACKEND_CACHE (cache), FALSE);
+
+	value = g_strdup (utc_str);
+
+	if (!(ret_val = e_file_cache_add_object (E_FILE_CACHE (cache), "server_utc_time", value)))
+		ret_val = e_file_cache_replace_object (E_FILE_CACHE (cache), "server_utc_time", value);
+
+	return ret_val;
+}
+
+const char *
+e_cal_backend_cache_get_server_utc_time (ECalBackendCache *cache)
+{
+
+	g_return_val_if_fail (E_IS_CAL_BACKEND_CACHE (cache), NULL);
+	
+       	return	e_file_cache_get_object (E_FILE_CACHE (cache), "server_utc_time");
+}
