@@ -26,12 +26,14 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <glib.h>
+#include <libsoup/soup-misc.h>
 #include "camel-groupwise-utils.h"
 
 #include <camel/camel-service.h>
 #include <camel/camel-multipart.h>
 #include <camel/camel-stream-mem.h>
 #include <camel/camel-address.h>
+#include <camel/camel-mime-message.h>
 
 #define SUBFOLDER_DIR_NAME     "subfolders"
 #define SUBFOLDER_DIR_NAME_LEN 10
@@ -258,6 +260,29 @@ e_path_rmdir (const char *prefix, const char *vpath)
 	return 0;
 }
 
+GSList *
+add_recipients(GSList *recipient_list, CamelAddress *recipients, int recipient_type)
+{
+	int total_add,i;
+	EGwItemRecipient *recipient ;
+	
+	total_add = camel_address_length (recipients) ;
+	for (i=0 ; i<total_add ; i++) {
+		const char *name = NULL, *addr = NULL ;
+		if(camel_internet_address_get ((CamelInternetAddress *)recipients, i , &name, &addr )) {
+
+			recipient = g_new0 (EGwItemRecipient, 1);
+
+			recipient->email = g_strdup (addr) ;
+			recipient->display_name = g_strdup (name) ;
+			recipient->type = recipient_type;
+			recipient->status = E_GW_ITEM_STAT_NONE ;
+			recipient_list= g_slist_append (recipient_list, recipient) ;
+		}
+	}
+	return recipient_list;
+}
+
 EGwItem *
 camel_groupwise_util_item_from_message (CamelMimeMessage *message, CamelAddress *from, CamelAddress *recipients)
 {
@@ -277,22 +302,20 @@ camel_groupwise_util_item_from_message (CamelMimeMessage *message, CamelAddress
 
 	/*Egroupwise item*/
 	item = e_gw_item_new_empty () ;
-
+	
 	/*poulate recipient list*/
-	total_add = camel_address_length (recipients) ;
-	for (i=0 ; i<total_add ; i++) {
-		const char *name = NULL, *addr = NULL ;
-		if(camel_internet_address_get ((CamelInternetAddress *)recipients, i , &name, &addr )) {
+	camel_address_remove(recipients,-1);
+	camel_address_cat (recipients, CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_TO)));
+	recipient_list=add_recipients(recipient_list,recipients,E_GW_ITEM_RECIPIENT_TO);
 
-			recipient = g_new0 (EGwItemRecipient, 1);
+	camel_address_remove(recipients,-1);
+	camel_address_cat (recipients, CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_CC)));
+	recipient_list=add_recipients(recipient_list,recipients,E_GW_ITEM_RECIPIENT_CC);
+	
+	camel_address_remove(recipients,-1);
+	camel_address_cat (recipients, CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_BCC)));
+	recipient_list=add_recipients(recipient_list,recipients,E_GW_ITEM_RECIPIENT_BC);
 
-			recipient->email = g_strdup (addr) ;
-			recipient->display_name = g_strdup (name) ;
-			recipient->type = E_GW_ITEM_RECIPIENT_TO;
-			recipient->status = E_GW_ITEM_STAT_NONE ;
-			recipient_list= g_slist_append (recipient_list, recipient) ;
-		}
-	}
 
 	/** Get the mime parts from CamelMimemessge **/
 	mp = (CamelMultipart *)camel_medium_get_content_object (CAMEL_MEDIUM (message));
@@ -307,48 +330,64 @@ camel_groupwise_util_item_from_message (CamelMimeMessage *message, CamelAddress
 		guint part_count ;
 		
 		part_count = camel_multipart_get_number (mp) ;
+		g_print ("Contains Multiple parts: %d\n", part_count) ;
 		for ( i=0 ; i<part_count ; i++) {
 			CamelContentType *type ;
 			CamelMimePart *part ;
 			CamelStreamMem *content = (CamelStreamMem *)camel_stream_mem_new () ;
 			CamelDataWrapper *dw = camel_data_wrapper_new () ;
-			EGwItemAttachment *attachment = g_new0 (EGwItemAttachment, 1) ;
+			EGwItemAttachment *attachment ; 
 			const char *disposition, *filename ;
 			char *buffer = NULL ;
 			char *mime_type = NULL ;
 			int len ;
-
+			/*
+			 * XXX:
+			 * Assuming the first part always is the actual message
+			 * and an attachment otherwise.....
+			 */
 			part = camel_multipart_get_part (mp, i) ;
 			dw = camel_medium_get_content_object (CAMEL_MEDIUM (part)) ;
-			
-
 			camel_data_wrapper_write_to_stream(dw, (CamelStream *)content) ;
 			buffer = g_malloc0 (content->buffer->len+1) ;
-			g_print (">>>>>> length:%d |||\n", content->buffer->len) ;
 			buffer = memcpy (buffer, content->buffer->data, content->buffer->len) ;
-			g_print (">>>>>> buffer: \n %s\n", buffer) ;
 			len = content->buffer->len ;
 
 			filename = camel_mime_part_get_filename (part) ;
-			if (!filename) {
-				/*the message*/
+			disposition = camel_mime_part_get_disposition (part) ;
+			mime_type = camel_data_wrapper_get_mime_type (dw) ;
+			type = camel_mime_part_get_content_type(part) ;
+
+			if (i == 0) {
+				e_gw_item_set_content_type (item, mime_type) ;
 				e_gw_item_set_message (item, buffer) ;
 			} else {
-				mime_type = camel_data_wrapper_get_mime_type (dw) ;
-				g_print (">>>>mime:%s |||\n", mime_type) ;
-				type = camel_mime_part_get_content_type(part) ;
-				disposition = camel_mime_part_get_disposition (part) ;
-				attachment->data = g_malloc0 (content->buffer->len+1) ;
-				attachment->data = memcpy (attachment->data, content->buffer->data, content->buffer->len) ;
-				attachment->name = g_strdup (filename) ;
+				attachment = g_new0 (EGwItemAttachment, 1) ;
+				if (filename) {
+					attachment->data = g_malloc0 (content->buffer->len+1) ;
+					attachment->data = memcpy (attachment->data, 
+							           content->buffer->data, 
+							           content->buffer->len) ;
+					attachment->size = content->buffer->len ;
+				} else {
+					char *temp_str ;
+					int temp_len ;
+					temp_str = soup_base64_encode (buffer, len) ;
+					temp_len = strlen (temp_str) ;
+					attachment->data = g_strdup (temp_str) ;
+					attachment->size = temp_len ;
+					g_free (temp_str) ;
+					temp_str = NULL ;
+					temp_len = 0 ;
+				}
+				attachment->name = g_strdup (filename ? filename : "") ;
 				attachment->contentType = g_strdup_printf ("%s/%s", type->type, type->subtype) ;
-				g_print (">>>>>> %s/%s <<<<<< \n", type->type, type->subtype) ;
-				attachment->size = content->buffer->len ;
 				
 				attach_list = g_slist_append (attach_list, attachment) ;
-				g_free (mime_type) ;
 			}
+
 			g_free (buffer) ;
+			g_free (mime_type) ;
 			camel_object_unref (content) ;
 
 		} /*end of for*/
@@ -357,16 +396,21 @@ camel_groupwise_util_item_from_message (CamelMimeMessage *message, CamelAddress
 		/*only message*/
 		CamelStreamMem *content = (CamelStreamMem *)camel_stream_mem_new () ;
 		CamelDataWrapper *dw = camel_data_wrapper_new () ;
+		CamelContentType *type ;
 		char *buffer = NULL ;
+		char *content_type = NULL ;
 			
 		dw = camel_medium_get_content_object (CAMEL_MEDIUM (message)) ;
+		type = camel_mime_part_get_content_type((CamelMimePart *)message) ;
+		content_type = g_strdup_printf ("%s/%s", type->type, type->subtype) ;
 		camel_data_wrapper_write_to_stream(dw, (CamelStream *)content) ;
 		buffer = g_malloc0 (content->buffer->len+1) ;
 		buffer = memcpy (buffer, content->buffer->data, content->buffer->len) ;
-				
+		e_gw_item_set_content_type (item, content_type) ;				
 		e_gw_item_set_message (item, buffer) ;
 		
 		g_free (buffer) ;
+		g_free (content_type) ;
 		camel_object_unref (content) ;
 	}
 	/*Populate EGwItem*/
