@@ -23,6 +23,7 @@
 
 #include <config.h>
 #include <string.h>
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtkalignment.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkentry.h>
@@ -33,6 +34,7 @@
 #include <libedataserverui/e-source-option-menu.h>
 #include <libedataserverui/e-destination-store.h>
 #include <libedataserverui/e-contact-store.h>
+#include <libedataserverui/e-book-auth-util.h>
 #include "e-name-selector-dialog.h"
 
 typedef struct {
@@ -53,6 +55,7 @@ static void     setup_name_selector_model     (ENameSelectorDialog *name_selecto
 static void     contact_activated             (ENameSelectorDialog *name_selector_dialog, GtkTreePath *path);
 static void     destination_activated         (ENameSelectorDialog *name_selector_dialog, GtkTreePath *path,
 					       GtkTreeViewColumn *column, GtkTreeView *tree_view);
+static gboolean destination_key_press         (ENameSelectorDialog *name_selector_dialog, GdkEventKey *event, GtkTreeView *tree_view);
 static void     remove_books                  (ENameSelectorDialog *name_selector_dialog);
 static void     contact_column_formatter      (GtkTreeViewColumn *column, GtkCellRenderer *cell,
 					       GtkTreeModel *model, GtkTreeIter *iter,
@@ -448,6 +451,8 @@ add_section (ENameSelectorDialog *name_selector_dialog,
 	gtk_box_pack_start (section.section_box, widget, TRUE, TRUE, 0);
 	g_signal_connect_swapped (section.destination_view, "row-activated",
 				  G_CALLBACK (destination_activated), name_selector_dialog);
+	g_signal_connect_swapped (section.destination_view, "key-press-event",
+				  G_CALLBACK (destination_key_press), name_selector_dialog);
 
 	gtk_widget_show_all (GTK_WIDGET (section.section_box));
 
@@ -535,12 +540,8 @@ source_selected (ENameSelectorDialog *name_selector_dialog, ESource *source)
 	remove_books (name_selector_dialog);
 
 	/* Start loading selected book */
-	name_selector_dialog->pending_book = e_book_new (source, NULL);
-	if (!name_selector_dialog->pending_book)
-		return;
-
-	e_book_async_open (name_selector_dialog->pending_book, TRUE,
-			   book_opened, name_selector_dialog);
+	name_selector_dialog->pending_book = e_load_book_source (source, book_opened,
+								 name_selector_dialog);
 }
 
 /* --------------- *
@@ -558,7 +559,11 @@ search_changed (ENameSelectorDialog *name_selector_dialog)
 
 	text = gtk_entry_get_text (name_selector_dialog->search_entry);
 	text_escaped = escape_sexp_string (text);
-	query_string = g_strdup_printf ("(contains \"file_as\" %s)", text_escaped);
+	query_string = g_strdup_printf ("(or (beginswith \"file_as\" %s) "
+					"    (beginswith \"full_name\" %s) "
+					"    (beginswith \"email\" %s) "
+					"    (beginswith \"nickname\" %s))",
+					text_escaped, text_escaped, text_escaped, text_escaped);
 	book_query = e_book_query_from_string (query_string);
 	g_free (query_string);
 	g_free (text_escaped);
@@ -662,6 +667,44 @@ destination_activated (ENameSelectorDialog *name_selector_dialog, GtkTreePath *p
 	e_destination_store_remove_destination (destination_store, destination);
 }
 
+static gboolean 
+destination_key_press (ENameSelectorDialog *name_selector_dialog, 
+		       GdkEventKey *event, GtkTreeView *tree_view)
+{
+	gint               section_index;
+	EDestinationStore *destination_store;
+	EDestination      *destination;
+	Section           *section;
+	GtkTreeIter        iter;
+
+	/* we only care about DEL key */
+	if (event->keyval != GDK_Delete)
+		return FALSE;
+
+	section_index = find_section_by_tree_view (name_selector_dialog, tree_view);
+	if (section_index < 0) {
+		g_warning ("ENameSelectorDialog got key press from unknown view!");
+		return FALSE;
+	}
+
+	section = &g_array_index (name_selector_dialog->sections, Section, section_index);
+	if (!e_name_selector_model_peek_section (name_selector_dialog->name_selector_model,
+						 section->name, NULL, &destination_store)) {
+		g_warning ("ENameSelectorDialog has a section unknown to the model!");
+		return FALSE;
+	}
+
+	if (!gtk_tree_selection_get_selected (gtk_tree_view_get_selection (tree_view), NULL, &iter))
+		return FALSE;
+
+	destination = e_destination_store_get_destination (destination_store, &iter);
+	g_assert (destination);
+
+	e_destination_store_remove_destination (destination_store, destination);
+
+	return TRUE;
+}
+
 static void
 transfer_button_clicked (ENameSelectorDialog *name_selector_dialog, GtkButton *transfer_button)
 {
