@@ -60,6 +60,7 @@ typedef enum {
 	E_GW_CONNECTION_STATUS_INVALID_CONNECTION,
 	E_GW_CONNECTION_STATUS_INVALID_OBJECT,
 	E_GW_CONNECTION_STATUS_INVALID_RESPONSE,
+	E_GW_CONNECTION_STATUS_NO_RESPONSE,
 	E_GW_CONNECTION_STATUS_OBJECT_NOT_FOUND,
 	E_GW_CONNECTION_STATUS_UNKNOWN_USER,
 	E_GW_CONNECTION_STATUS_BAD_PARAMETER,
@@ -69,6 +70,10 @@ typedef enum {
 	E_GW_CONNECTION_STATUS_UNKNOWN
 } EGwConnectionStatus;
 
+#define E_GW_CURSOR_POSITION_CURRENT "current"
+#define E_GW_CURSOR_POSITION_START "start"
+#define E_GW_CURSOR_POSITION_END "end"
+
 SoupSoapResponse   *e_gw_connection_send_message (EGwConnection *cnc, SoupSoapMessage *msg);
 EGwConnectionStatus e_gw_connection_parse_response_status (SoupSoapResponse *response);
 const char         *e_gw_connection_get_error_message (EGwConnectionStatus status);
@@ -89,6 +94,8 @@ const char         *e_gw_connection_get_session_id (EGwConnection *cnc);
 const char         *e_gw_connection_get_user_name (EGwConnection *cnc);
 const char         *e_gw_connection_get_user_email (EGwConnection *cnc);
 const char         *e_gw_connection_get_user_uuid (EGwConnection *cnc);
+const char 	   *e_gw_connection_get_version (EGwConnection *cnc);
+const char	   *e_gw_connection_get_server_time (EGwConnection *cnc) ;
 
 
 time_t              e_gw_connection_get_date_from_string (const char *dtstring);
@@ -106,17 +113,17 @@ EGwConnectionStatus e_gw_connection_create_book (EGwConnection *cnc, char *book_
 EGwConnectionStatus e_gw_connection_remove_book (EGwConnection *cnc, char *book_uid);
 EGwConnectionStatus e_gw_connection_get_address_book_list (EGwConnection *cnc, GList **container_list);
 EGwConnectionStatus e_gw_connection_get_address_book_id ( EGwConnection *cnc, char *book_name, char**id , gboolean *is_writable);
-EGwConnectionStatus e_gw_connection_get_categories  (EGwConnection *cnc, GHashTable *categories_by_id, GHashTable *categoreis_by_name);
+EGwConnectionStatus e_gw_connection_get_categories  (EGwConnection *cnc, GHashTable **categories_by_id, GHashTable **categoreis_by_name);
 EGwConnectionStatus e_gw_connection_add_members (EGwConnection *cnc, const char *group_id, GList *member_ids);
 EGwConnectionStatus e_gw_connection_remove_members (EGwConnection *cnc, const char *group_id, GList *member_ids);
 EGwConnectionStatus e_gw_connection_get_items_from_ids (EGwConnection *cnc, const char *container, const char *view, GPtrArray *item_ids, GList **list);
 
 EGwConnectionStatus e_gw_connection_create_cursor (EGwConnection *cnc, const char *container, const char *view, EGwFilter *filter, int *cursor);
 EGwConnectionStatus e_gw_connection_destroy_cursor (EGwConnection *cnc, const char *container,  int cursor);
-EGwConnectionStatus e_gw_connection_read_cursor (EGwConnection *cnc, const char *container, int cursor, gboolean forward, int count, GList **item_list);
+EGwConnectionStatus e_gw_connection_read_cursor (EGwConnection *cnc, const char *container, int cursor, gboolean forward, int count, const char *cursor_seek, GList **item_list);
 EGwConnectionStatus e_gw_connection_position_cursor (EGwConnection *cnc, const char *container, int cursor, const char *seek, int offset);
 
-EGwConnectionStatus e_gw_connection_get_quick_messages (EGwConnection *cnc, const char *container, const char *view, const char *start_date, const char *message_list, const char *item_types, const char *item_sources, int count, GSList **item_list);
+EGwConnectionStatus e_gw_connection_get_quick_messages (EGwConnection *cnc, const char *container, const char *view, char **start_date, const char *message_list, const char *item_types, const char *item_sources, int count, GSList **item_list);
 
 EGwConnectionStatus e_gw_connection_create_folder(EGwConnection *cnc, const char *parent_name,const char *folder_name, char **container_id) ;
 EGwConnectionStatus
@@ -135,6 +142,7 @@ EGwConnectionStatus e_gw_connection_purge_deleted_items (EGwConnection *cnc);
 
 EGwConnectionStatus e_gw_connection_mark_read(EGwConnection *cnc, GList *item_ids) ;
 EGwConnectionStatus e_gw_connection_mark_unread(EGwConnection *cnc, GList *item_ids) ;
+EGwConnectionStatus e_gw_connection_reply_item (EGwConnection *cnc, const char *id, const char *view, EGwItem **item) ;
 G_END_DECLS
 
 #endif
